@@ -1,9 +1,7 @@
 class filter_data:
-    def __init__(self):
-        self.self=self
         '''In multiple filter function you can filter upto ten data 10 
         only you have to pass yor value as list(respect to multiple filter)'''
-    def filter_equalto_multiple(self,df,column,val):#val as list
+    def filter_equalto_multiple(df,column,val):#val as list
         if type(val)==list and len(val)<=10:
             if len(val)==2:
                 df=df.filter((col(column)==val[0])|(col(column)==val[1]))
@@ -36,11 +34,11 @@ class filter_data:
             
                 print("Your List length is more than 10 ➡ currently",len(val))
         return df
-    def filter_equalto(self,df,column,val):
+    def filter_equalto(df,column,val):
         df=df.filter(col(column)==val)
         print("New Shape of the data frame",(df.count(),len(df.coulumns)))
         return df
-    def filter_not_equalto_multiple(self,df,column,val):#val as list
+    def filter_not_equalto_multiple(df,column,val):#val as list
         if type(val)==list and len(val)<=10:
             if len(val)==2:
                 df=df.filter((col(column)!=val[0])|(col(column)!=val[1]))
@@ -74,11 +72,11 @@ class filter_data:
                 print("Your List length is more than 10 ➡ currently",len(val))
         return df
         
-    def filter_not_equalto(self,df,column,val):
+    def filter_not_equalto(df,column,val):
         df=df.filter(col(column)!=val)
         print('New shape of the Dat set',(df.count(), len(df.columns)))
         return df
-    def filter_null(self,df,column):
+    def filter_null(df,column):
         df=df.filter(col(column).isNull())
         print('New shape of the Dat set',(df.count(), len(df.columns)))
         return df
